@@ -3,7 +3,7 @@ import userEvent from '@testing-library/user-event';
 import { TestProvider } from 'test/helpers/TestProvider';
 import { selectOptionInTest } from 'test/helpers/selectOptionInTest';
 
-import { getRouteComponentProps } from 'app/core/navigation/__mocks__/routeProps';
+import { getRouteComponentProps } from 'app/core/navigation/mocks/routeProps';
 
 import { mockToolkitActionCreator } from '../../../../test/core/redux/mocks';
 import { addRootReducer } from '../../../store/configureStore';
@@ -53,6 +53,7 @@ jest.mock('@grafana/runtime', () => ({
 jest.mock('app/core/core', () => {
   return {
     contextSrv: {
+      ...jest.requireActual('app/core/core').contextSrv,
       hasPermission: () => true,
     },
   };
@@ -99,7 +100,7 @@ describe('Report Scheduling', () => {
     expect(screen.getByRole('radio', { name: 'Weekly' })).toBeChecked();
     expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
     expect(
-      screen.getByText('The report will be sent immediately after it is saved and will be sent every week.')
+      screen.getByText("This report will be sent immediately after it's saved and then every week.")
     ).toBeInTheDocument();
     expect(screen.queryByLabelText(/report schedule start date/i)).toBeInTheDocument();
     expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('');
@@ -132,11 +133,11 @@ describe('Report Scheduling', () => {
       await user.click(screen.getByRole('radio', { name: /once/i }));
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
-      expect(screen.getByText('The report will be sent immediately after it is saved.')).toBeInTheDocument();
+      expect(screen.getByText("This report will be sent immediately after it's saved.")).toBeInTheDocument();
       await user.click(screen.getByRole('radio', { name: /later/i }));
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
-      expect(screen.getByText(/The report will be sent: Once on January 1, 2020/i)).toBeInTheDocument();
+      expect(screen.getByText(/This report will be sent: Once on January 1, 2020/i)).toBeInTheDocument();
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
     });
 
@@ -145,7 +146,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByRole('radio', { name: 'Send now' })).toBeChecked();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
       expect(
-        screen.getByText('The report will be sent immediately after it is saved and will be sent every hour.')
+        screen.getByText("This report will be sent immediately after it's saved and then every hour.")
       ).toBeInTheDocument();
       await user.click(screen.getByRole('radio', { name: /later/i }));
       await selectDate('January 1, 2020');
@@ -153,14 +154,14 @@ describe('Report Scheduling', () => {
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
-      expect(screen.getByText(/The report will be sent: Hourly at minute 00/i)).toBeInTheDocument();
+      expect(screen.getByText(/This report will be sent: Hourly at minute 00/i)).toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('');
       await user.click(screen.getByLabelText(/report schedule end date/i));
       await user.click(screen.getByRole('button', { name: 'January 11, 2020' }));
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('01/11/2020');
       expect(screen.getByText(/end time/i)).toBeInTheDocument();
       expect(
-        screen.getByText(/The report will be sent: Hourly at minute 00, January 1, 2020 - January 11, 2020/i)
+        screen.getByText(/This report will be sent: Hourly at minute 00, January 1, 2020 - January 11, 2020/i)
       ).toBeInTheDocument();
     });
 
@@ -180,7 +181,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
       expect(
-        screen.getByText(/The report will be sent immediately after it is saved and will be sent every day./i)
+        screen.getByText(/This report will be sent immediately after it's saved and then every day./i)
       ).toBeInTheDocument();
     });
     it('weekly', async () => {
@@ -190,7 +191,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
       expect(
-        screen.getByText(/The report will be sent immediately after it is saved and will be sent every week./i)
+        screen.getByText(/This report will be sent immediately after it's saved and then every week./i)
       ).toBeInTheDocument();
       await user.click(screen.getByRole('radio', { name: /later/i }));
       await selectDate('January 1, 2020');
@@ -198,7 +199,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/01/2020');
       expect(screen.getByText(/start time/i)).toBeVisible();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
-      expect(screen.getByText(/The report will be sent: Every Wednesday at 00:00/i));
+      expect(screen.getByText(/This report will be sent: Every Wednesday at 00:00/i));
     });
     it('monthly', async () => {
       await user.click(screen.getByRole('radio', { name: /monthly/i }));
@@ -213,13 +214,13 @@ describe('Report Scheduling', () => {
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(
         screen.getByText(
-          /The report will be sent: Monthly on the 1st day at 00:00 UTC-05:00, January 1, 2020 - January 11, 2020./i
+          /This report will be sent: Monthly on the 1st day at 00:00 UTC-05:00, January 1, 2020 - January 11, 2020./i
         )
       ).toBeInTheDocument();
       await user.click(screen.getByRole('checkbox', { name: /send on the last day of month/i }));
       expect(screen.getByLabelText(/report schedule start date/i)).toHaveValue('01/31/2020');
       await user.clear(screen.getByLabelText(/report schedule end date/i));
-      expect(screen.getByText(/The report will be sent: Monthly on the last day at 00:00./i)).toBeInTheDocument();
+      expect(screen.getByText(/This report will be sent: Monthly on the last day at 00:00./i)).toBeInTheDocument();
       await user.click(screen.getByRole('radio', { name: /send now/i }));
       expect(screen.queryByRole('checkbox', { name: /send on the last day of month/i })).not.toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule start date/i)).not.toBeVisible();
@@ -227,7 +228,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(
-        screen.getByText('The report will be sent immediately after it is saved and will be sent every month.')
+        screen.getByText("This report will be sent immediately after it's saved and then every month.")
       ).toBeInTheDocument();
     });
 
@@ -238,10 +239,10 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/custom frequency/i)).toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeInTheDocument();
       expect(
-        screen.getByText(/The report will be sent immediately after it is saved and will be sent every 2 hours./i)
+        screen.getByText(/This report will be sent immediately after it's saved and then every 2 hours./i)
       ).toBeInTheDocument();
       await user.click(screen.getByRole('radio', { name: /later/i }));
-      expect(screen.getByText(/The report will be sent: Every 2 hours./i)).toBeInTheDocument();
+      expect(screen.getByText(/This report will be sent: Every 2 hours./i)).toBeInTheDocument();
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toBeVisible();
       await selectDate('January 1, 2020');
@@ -250,7 +251,7 @@ describe('Report Scheduling', () => {
       await selectOptionInTest(screen.getByLabelText(/custom frequency/i), 'months');
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(
-        screen.getByText(/The report will be sent: Every 2 months, January 1, 2020 - January 11, 2020./i)
+        screen.getByText(/This report will be sent: Every 2 months, January 1, 2020 - January 11, 2020./i)
       ).toBeInTheDocument();
     });
 
@@ -286,7 +287,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByDisplayValue('03:20')).toBeInTheDocument();
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
-      expect(screen.getByText('The report will be sent: Once on March 16, 2020.')).toBeInTheDocument();
+      expect(screen.getByText('This report will be sent: Once on March 16, 2020.')).toBeInTheDocument();
     });
 
     it('hourly', () => {
@@ -314,7 +315,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeChecked();
       expect(
         screen.getByText(
-          /The report will be sent: Hourly at minute 20, March 16, 2020 - April 16, 2020, Monday to Friday/i
+          /This report will be sent: Hourly at minute 20, March 16, 2020 - April 16, 2020, Monday to Friday/i
         )
       ).toBeInTheDocument();
     });
@@ -330,7 +331,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('');
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).not.toBeChecked();
-      expect(screen.getByText('The report will be sent: Daily at 03:20 UTC+01:00.')).toBeInTheDocument();
+      expect(screen.getByText('This report will be sent: Daily at 03:20 UTC+01:00.')).toBeInTheDocument();
     });
 
     it('weekly', () => {
@@ -344,7 +345,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toBeInTheDocument();
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('');
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
-      expect(screen.getByText('The report will be sent: Every Monday at 03:20 UTC+01:00.')).toBeInTheDocument();
+      expect(screen.getByText('This report will be sent: Every Monday at 03:20 UTC+01:00.')).toBeInTheDocument();
     });
 
     it('monthly', () => {
@@ -365,7 +366,7 @@ describe('Report Scheduling', () => {
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
       expect(screen.getByRole('checkbox', { name: /send on the last day of month/i })).toBeChecked();
       expect(
-        screen.getByText('The report will be sent: Monthly on the last day at 03:20 UTC+01:00.')
+        screen.getByText('This report will be sent: Monthly on the last day at 03:20 UTC+01:00.')
       ).toBeInTheDocument();
     });
 
@@ -391,7 +392,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByLabelText(/report schedule end date/i)).toHaveValue('');
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
       expect(screen.queryByRole('checkbox', { name: /send on the last day of month/i })).not.toBeInTheDocument();
-      expect(screen.getByText('The report will be sent: Every 3 months, from March 16, 2020.')).toBeInTheDocument();
+      expect(screen.getByText('This report will be sent: Every 3 months, from March 16, 2020.')).toBeInTheDocument();
     });
 
     it('custom (hours)', () => {
@@ -412,7 +413,7 @@ describe('Report Scheduling', () => {
       expect(screen.getByRole('checkbox', { name: /monday to friday/i })).toBeChecked();
       expect(screen.queryByRole('checkbox', { name: /send on the last day of month/i })).not.toBeInTheDocument();
       expect(
-        screen.getByText('The report will be sent: Every 3 hours, from 03:20 UTC+01:00, Monday to Friday.')
+        screen.getByText('This report will be sent: Every 3 hours, from 03:20 UTC+01:00, Monday to Friday.')
       ).toBeInTheDocument();
     });
 
@@ -426,7 +427,7 @@ describe('Report Scheduling', () => {
       expect(screen.queryByLabelText(/report schedule end date/i)).not.toBeInTheDocument();
       expect(screen.queryByRole('checkbox', { name: /monday to friday/i })).not.toBeInTheDocument();
       expect(screen.queryByRole('checkbox', { name: /send on the last day of month/i })).not.toBeInTheDocument();
-      expect(screen.getByText('The report will not be sent.')).toBeInTheDocument();
+      expect(screen.getByText('This report will not be sent.')).toBeInTheDocument();
     });
   });
 
